
# grafana Resource Provider

The grafana resource provider for Pulumi lets you creating resources in [grafana](https://www.grafana.com). To use
this package, please [install the Pulumi CLI first](https://pulumi.com/).

## Installing

This package is available in many languages in the standard packaging formats.

### Node.js (Java/TypeScript)

To use from JavaScript or TypeScript in Node.js, install using either `npm`:

```
$ npm install @pulumiverse/grafana
```

or `yarn`:

```
$ yarn add @pulumiverse/grafana
```

### Python

To use from Python, install using `pip`:

```
$ pip install pulumiverse_grafana
```

### Go

To use from Go, use `go get` to grab the latest version of the library

```
$ go get github.com/pulumiverse/pulumi-grafana/sdk/go/...
```

### .NET

To use from Dotnet, use `dotnet add package` to install into your project. You must specify the version if it is a pre-release version.


```
$ dotnet add package Pulumiverse.Grafana
```

## Reference

See the Pulumi registry for API docs:

https://www.pulumi.com/registry/packages/grafana/api-docs/
